Fluxy class
The entry point for the Fluxy framework.
Constructors
- Fluxy()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
addMiddleware(
FluxyMiddleware middleware) → void - Registers a global middleware.
-
autoRegister(
) → void - Automatically registers modular plugins found in the project.
-
back<
T> ([T? result]) → void -
debug(
{required Widget child}) → Widget - Helper to wrap the app with DevTools or other debug features.
-
find<
T> ({String? tag}) → T - Alias for dependency injection (same as use).
-
findPlugin(
String name) → dynamic - Finds a plugin by its unique name.
-
init(
{bool strictMode = false, bool debugMode = true}) → Future< void> -
log(
String tag, String type, String message) → void - Standardized Fluxy logger for internal and plugin use.
-
off<
T, TO> (String routeName, {TO? result, Object? arguments}) → Future< T?> -
offAll<
T> (String routeName, {Object? arguments}) → Future< T?> -
onError(
FluxyErrorHandler handler) → void - Registers a global error handler for the framework.
-
printStabilitySummary(
) → void - Prints a summary of stability interventions. Prints a summary of stability interventions.
-
register(
FluxyPlugin plugin) → void - Registers a plugin to the engine manually.
-
registerRegistry(
void fn()) → void - Internal: App-side registry hook
-
to<
T> (String routeName, {Object? arguments}) → Future< T?> -
use<
T> ({String? tag}) → T - Shorthand for dependency injection.
-
verifyIntegrity(
) → void - Performs a deep architectural health check. Used primarily in Strict Mode to ensure the engine and plugins are synchronized.